# Sobre o e-Democracia

O portal e-Democracia da Câmara dos Deputados é um mecanismo múltiplo de participação, composto de variadas ferramentas. Significa dizer que são disponibilizadas diversas modalidades de interação, que podem ser utilizadas segundo o interesse, habilidade e motivação de cada cidadão.

O principal objetivo da plataforma é aprimorar o relacionamento entre cidadãos e deputados, fortalecendo o princípio representativo, de modo a mitigar um dos mais importantes déficits democráticos apontados pela literatura, qual seja a sensação de distanciamento entre a sociedade e seus representantes, em especial os do poder legislativo. 

Nesse sentido, o portal e-Democracia contribui para a busca por uma maior sintonia entre a opinião popular e a atuação dos parlamentares, dinâmica descrita no meio acadêmico pelo termo representação circular. 

Além disso, objetiva-se contribuir com a ampliação da transparência no processo legislativo e com uma melhor compreensão, pela sociedade, da complexidade do trabalho legislativo .

Criado em junho de 2009, o portal e-Democracia surgiu com o formato de projeto piloto, abrigando inicialmente duas discussões, organizadas em comunidades legislativas virtuais. Por meio dessas comunidades, foram discutidos com a sociedade dois projetos de lei específicos, que estavam em tramitação na Câmara dos Deputados: um sobre a política de mudança do clima e o outro sobre o estatuto da juventude.

Ao longo do tempo, os resultados dessas discussões, bem como o expressivo interesse da sociedade em participar do ambiente instituído, levaram à criação de novas comunidades legislativas virtuais, sobre diversos temas. 

Com isso, o portal deixou de ser um mero projeto piloto para institucionalizar-se através da Resolução 49/2013, que criou a Seção de Gestão do portal e-Democracia, no âmbito organizacional do Laboratório Hacker da Câmara dos Deputados, subordinado administrativamente à Diretoria Geral da Casa. 

No ano de 2016 o portal e-Democracia passou por ampla reformulação, que deu origem ao site como ele é hoje. Contudo, ainda é possível acessar o antigo ambiente, que está mantido para fins de consulta do histórico das discussões produzidas até então.

## Ferramentas de Participação

O portal e-Democracia da Câmara dos Deputados abriga discussões temáticas sobre assuntos específicos em tramitação na Casa, bem como debates livres, criados pelos próprios usuários da plataforma.  

A organização dessas discussões aconteciam originalmente no âmbito das chamadas Comunidades Legislativas Virtuais, criadas mediante demanda dos deputados (relator da matéria ou presidente de comissão parlamentar), sendo nesses espaços disponibilizadas variadas ferramentas de participação.

A partir da mencionada reformulação do portal, levada a cabo ao longo do ano de 2016, o protagonismo do cidadão no ambiente participativo do portal e-Democracia passa a assumir um novo patamar de relevância. Uma das inovações, por exemplo, está em permitir, já na página inicial do site (home), a personalização da exibição dos conteúdos participativos da plataforma conforme os temas de preferência do Usuário. A tela abaixo representa essa dinâmica: 

![Home (página inicial) do portal e-Democracia](images/edemocracia1.png)

Conforme se observa, já no seu primeiro contato com o sistema o cidadão tem a possibilidade de redefinir as sugestões de oportunidades de participação ofertadas pela plataforma clicando no botão “selecione os temas de seu interesse”. 

A partir dessa seleção, o portal promove uma “filtragem” dos conteúdos de todas as ferramentas de interação, com base nos parâmetros informados, facilitando a localização, pelo usuário, daquilo que é mais importante, segundo sua avaliação pessoal. 

A ideia orientadora dessa nova modalidade de interface é personalizar o fluxo de informações que é apresentado ao cidadão, facilitando sua participação na plataforma. Essa abordagem substitui a “curadoria de conteúdos” até então feita pela equipe do portal e-Democracia, a quem cabia definir quais seriam os temas em destaques na página inicial do portal. Esse conceito está presente também na reformulação de cada um dos mecanismos de participação do site.
A nova página inicial do portal e-Democracia, como visto, representa uma mudança de abordagem na apresentação dos conteúdos da plataforma, que deixam de ser organizados em Comunidades Legislativas, para serem apresentados em raias diferenciadas por modalidades de participação – ou ferramentas de participação. Nelas o cidadão pode interagir com os deputados e outros cidadãos através de fóruns de discussão, edição colaborativa de textos legislativos e questionamentos ao vivo, conforme se descreve a seguir.